@@ -1,13 +1,15 @@
 use std::fs;
-use std::path::PathBuf;
+use std::path::Path;
 
-pub fn path_stem(path: &str) -> String {
-    PathBuf::from(path)
-        .file_stem()
+pub fn mod_from_rust_path(code_path: &str, crate_path: &str) -> String {
+    Path::new(code_path)
+        .strip_prefix(Path::new(crate_path).join("src"))
         .unwrap()
-        .to_os_string()
+        .with_extension("")
+        .into_os_string()
         .into_string()
         .unwrap()
+        .replace('/', "::")
 }
 
 pub fn with_changed_file<F: FnOnce()>(path: &str, append_content: &str, f: F) {
